#!/bin/bash

#Change this variables if desired
binary=matmul
folder=study 
#####################################################

csvname=cycles.csv
echo "maxVL,cache_size,cycles" > $folder/$csvname

#prepare the reference configure file. Do not change this.
cp ../musa_redistributable/tasksim/etc/conf/riscv_reference.conf config.conf
num=`grep -Fn '[DL1Cache]' config.conf | cut -d ':' -f1`

#Run with two vector lengths
for maxVL in 16 32
do
	#run
	trace_name=${binary}_${maxVL}
	#convert traces to prv
	../vehave-EPI-0.7-development-2020-12-01-2200/share/vehave2prv/vehave2prv ${folder}/vehave_traces/${trace_name}.trace
	#simulate different cache sizes
	for CACHE_SIZE in 128 256 512 1024 2048 4096 
	do
		#sim
		trace_sim_name=${folder}/${trace_name}_sim_${CACHE_SIZE}
		awk -v line=$num -v cache=$CACHE_SIZE 'NR==line,/size*/{sub(/size.*/, "size = "cache)} 1' ../musa_redistributable/tasksim/etc/conf/riscv_reference.conf > config_${CACHE_SIZE}.conf 
		../musa_redistributable/tasksim/bin/tasksim.sh config_${CACHE_SIZE}.conf ${trace_sim_name} ${trace_name}
		
		#read results
		cycles=`cat ${trace_sim_name}.stats | grep "Final cycle count" | awk '{print($NF)}'`
		echo "$maxVL,$CACHE_SIZE,$cycles" >> $folder/$csvname
	done

done


mkdir study/original_traces
mv *.{pcf,row,prv} study/original_traces/.

rm -f config.conf
mv config_*.conf $folder/.
